==> igniteui-react-inputs-18.6.1.tgz: package/esm5/lib/NativeUIXInputsFactory.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { INativeUIElementFactory_$type } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
import { XInputGroup } from "./XInputGroup";
import { XInput } from "./XInput";
import { XInputBridge } from "./XInputBridge";
import { NativeUIInput } from "igniteui-react-core";
import { XButton } from "./XButton";
import { XButtonBridge } from "./XButtonBridge";
import { NativeUIButton } from "igniteui-react-core";
import { XCheckbox } from "./XCheckbox";
import { XCheckboxBridge } from "./XCheckboxBridge";
import { NativeUICheckbox } from "igniteui-react-core";
import { XIcon } from "./XIcon";
import { XIconBridge } from "./XIconBridge";
import { NativeUIIcon } from "igniteui-react-core";
import { Popup } from "igniteui-react-core";
import { XPopupBridge } from "./XPopupBridge";
import { NativeUIPopup } from "igniteui-react-core";
/**
 * @hidden
 */
var NativeUIXInputsFactory = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIXInputsFactory, _super);
    function NativeUIXInputsFactory() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = 2;
        return _this;
    }
    Object.defineProperty(NativeUIXInputsFactory, "b", {
        get: function () {
            if (NativeUIXInputsFactory.a == null) {
                NativeUIXInputsFactory.a = new NativeUIXInputsFactory();
            }
            return NativeUIXInputsFactory.a;
        },
        enumerable: false,
        configurable: true
    });
    NativeUIXInputsFactory.j = function () {
        NativeUIComponent.ap(NativeUIXInputsFactory.b);
    };
    Object.defineProperty(NativeUIXInputsFactory.prototype, "flavor", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    NativeUIXInputsFactory.prototype.createComponent = function (a, b, c) {
        switch (b) {
            case 1:
                this.d(a, c);
                break;
            case 6:
                this.e(a, c);
                break;
            case 10:
                this.g(a, c);
                break;
            case 2:
                this.h(a, c);
                break;
            case 11:
                this.f(a, c);
                break;
            case 12:
                this.i(a, c);
                break;
        }
    };
    NativeUIXInputsFactory.prototype.createComponentSync = function (a, b, c) {
        this.createComponent(a, b, c);
    };
    NativeUIXInputsFactory.prototype.supportsComponent = function (a) {
        switch (a) {
            case 1: return true;
            case 6: return true;
            case 10: return true;
            case 2: return true;
            case 11: return true;
            case 12: return true;
        }
        return false;
    };
    NativeUIXInputsFactory.prototype.h = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XInputGroup();
        f.provideContainer(e);
        var g = e.getExternal(f, e.rootWrapper, null);
        var h = c.createElement("div");
        h.setRawStyleProperty("width", "100%");
        var i = c.getSubRenderer(h);
        var j = new XInput();
        j.provideContainer(i);
        var k = e.getExternal(j, i.rootWrapper, null);
        f.appendContentChild(h);
        f.inputs.add(j);
        var l = new XInputBridge(f);
        var m = new NativeUIInput();
        m.al = d;
        m.d = l;
        b(m);
    };
    NativeUIXInputsFactory.prototype.d = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XButton();
        f.provideContainer(e);
        f.ff = "none";
        var g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
        var h = new XButtonBridge(f);
        var i = new NativeUIButton();
        i.al = d;
        i.d = h;
        b(i);
    };
    NativeUIXInputsFactory.prototype.e = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XCheckbox();
        f.provideContainer(e);
        var g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
        var h = new XCheckboxBridge(f);
        var i = new NativeUICheckbox();
        i.al = d;
        i.d = h;
        b(i);
    };
    NativeUIXInputsFactory.prototype.g = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XIcon();
        f.provideContainer(e);
        var g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
        var h = new XIconBridge(f);
        var i = new NativeUIIcon();
        i.al = d;
        i.d = h;
        var j = c.createElement("div");
        var k = c.getSubRenderer(j);
        var l = new XButton();
        l.provideContainer(k);
        l.e = 4;
        l.ff = "none";
        var m = k.getExternal(l, k.rootWrapper, k.getExternal(l, null, null));
        var n = new XButtonBridge(l);
        var o = new NativeUIButton();
        o.al = j;
        o.d = n;
        o.bk = i;
        b(o);
    };
    NativeUIXInputsFactory.prototype.f = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XIcon();
        f.provideContainer(e);
        var g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
        var h = new XIconBridge(f);
        var i = new NativeUIIcon();
        i.al = d;
        i.d = h;
        b(i);
    };
    NativeUIXInputsFactory.prototype.i = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new Popup();
        f.provideRenderer(e);
        var g = new XPopupBridge(f);
        var h = new NativeUIPopup();
        h.al = d;
        h.d = g;
        b(h);
    };
    NativeUIXInputsFactory.$t = markType(NativeUIXInputsFactory, 'NativeUIXInputsFactory', Base.$, [INativeUIElementFactory_$type]);
    NativeUIXInputsFactory.a = null;
    return NativeUIXInputsFactory;
}(Base));
export { NativeUIXInputsFactory };

==> igniteui-react-inputs-18.7.3.tgz: package/esm5/lib/NativeUIXInputsFactory.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { INativeUIElementFactory_$type } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
import { XInputGroup } from "./XInputGroup";
import { XInput } from "./XInput";
import { XInputBridge } from "./XInputBridge";
import { NativeUIInput } from "igniteui-react-core";
import { XButton } from "./XButton";
import { XButtonBridge } from "./XButtonBridge";
import { NativeUIButton } from "igniteui-react-core";
import { XCheckbox } from "./XCheckbox";
import { XCheckboxBridge } from "./XCheckboxBridge";
import { NativeUICheckbox } from "igniteui-react-core";
import { XIcon } from "./XIcon";
import { XIconBridge } from "./XIconBridge";
import { NativeUIIcon } from "igniteui-react-core";
import { Popup } from "igniteui-react-core";
import { XPopupBridge } from "./XPopupBridge";
import { NativeUIPopup } from "igniteui-react-core";
/**
 * @hidden
 */
var NativeUIXInputsFactory = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIXInputsFactory, _super);
    function NativeUIXInputsFactory() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = 2;
        return _this;
    }
    Object.defineProperty(NativeUIXInputsFactory, "b", {
        get: function () {
            if (NativeUIXInputsFactory.a == null) {
                NativeUIXInputsFactory.a = new NativeUIXInputsFactory();
            }
            return NativeUIXInputsFactory.a;
        },
        enumerable: false,
        configurable: true
    });
    NativeUIXInputsFactory.j = function () {
        NativeUIComponent.ar(NativeUIXInputsFactory.b);
    };
    Object.defineProperty(NativeUIXInputsFactory.prototype, "flavor", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    NativeUIXInputsFactory.prototype.createComponent = function (a, b, c) {
        switch (b) {
            case 1:
                this.d(a, c);
                break;
            case 6:
                this.e(a, c);
                break;
            case 10:
                this.g(a, c);
                break;
            case 2:
                this.h(a, c);
                break;
            case 11:
                this.f(a, c);
                break;
            case 12:
                this.i(a, c);
                break;
        }
    };
    NativeUIXInputsFactory.prototype.createComponentSync = function (a, b, c) {
        this.createComponent(a, b, c);
    };
    NativeUIXInputsFactory.prototype.supportsComponent = function (a) {
        switch (a) {
            case 1: return true;
            case 6: return true;
            case 10: return true;
            case 2: return true;
            case 11: return true;
            case 12: return true;
        }
        return false;
    };
    NativeUIXInputsFactory.prototype.h = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XInputGroup();
        f.provideContainer(e);
        var g = e.getExternal(f, e.rootWrapper, null);
        var h = c.createElement("div");
        h.setRawStyleProperty("width", "100%");
        var i = c.getSubRenderer(h);
        var j = new XInput();
        j.provideContainer(i);
        var k = e.getExternal(j, i.rootWrapper, null);
        f.appendContentChild(h);
        f.inputs.add(j);
        var l = new XInputBridge(f);
        var m = new NativeUIInput();
        m.an = d;
        m.d = l;
        b(m);
    };
    NativeUIXInputsFactory.prototype.d = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XButton();
        f.provideContainer(e);
        f.ff = "none";
        var g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
        var h = new XButtonBridge(f);
        var i = new NativeUIButton();
        i.an = d;
        i.d = h;
        b(i);
    };
    NativeUIXInputsFactory.prototype.e = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XCheckbox();
        f.provideContainer(e);
        var g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
        var h = new XCheckboxBridge(f);
        var i = new NativeUICheckbox();
        i.an = d;
        i.d = h;
        b(i);
    };
    NativeUIXInputsFactory.prototype.g = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XIcon();
        f.provideContainer(e);
        var g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
        var h = new XIconBridge(f);
        var i = new NativeUIIcon();
        i.an = d;
        i.d = h;
        var j = c.createElement("div");
        var k = c.getSubRenderer(j);
        var l = new XButton();
        l.provideContainer(k);
        l.e = 4;
        l.ff = "none";
        var m = k.getExternal(l, k.rootWrapper, k.getExternal(l, null, null));
        var n = new XButtonBridge(l);
        var o = new NativeUIButton();
        o.an = j;
        o.d = n;
        o.bm = i;
        b(o);
    };
    NativeUIXInputsFactory.prototype.f = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new XIcon();
        f.provideContainer(e);
        var g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
        var h = new XIconBridge(f);
        var i = new NativeUIIcon();
        i.an = d;
        i.d = h;
        b(i);
    };
    NativeUIXInputsFactory.prototype.i = function (a, b) {
        var c = a;
        var d = c.createElement("div");
        var e = c.getSubRenderer(d);
        var f = new Popup();
        f.provideRenderer(e);
        var g = new XPopupBridge(f);
        var h = new NativeUIPopup();
        h.an = d;
        h.d = g;
        b(h);
    };
    NativeUIXInputsFactory.$t = markType(NativeUIXInputsFactory, 'NativeUIXInputsFactory', Base.$, [INativeUIElementFactory_$type]);
    NativeUIXInputsFactory.a = null;
    return NativeUIXInputsFactory;
}(Base));
export { NativeUIXInputsFactory };
